@@ -22,8 +22,11 @@ for my $opt ( sort keys %$valid_values ) {
     }
 }
 
-$new->choose( [], Data_Test_Arguments::mixed_options_1() );
-$new->choose( [], Data_Test_Arguments::mixed_options_2() );
+my $mixed_options_1 = Data_Test_Arguments::mixed_options_1();
+$new->choose( [], $mixed_options_1 );
+
+my $mixed_options_2 = Data_Test_Arguments::mixed_options_2();
+$new->choose( [], $mixed_options_1 );
 
 
 print "<End_mc_va>\n";
